get_weighted_proportions: A function to calculate group proportions for categorical...

Description Usage Arguments Value Examples

View source: R/HandleDescriptives.R

Description

A function to calculate group proportions for categorical variables in sample weighted data

Usage

1

Arguments

x

A vector of the factor for which proportions to be calculated.

y

A vector of weights for each of the values in x

Value

A numeric vector containing the proportions for each level of factor

Examples

1
get_weighted_proportions(highested,sampleweights)

cbannard/imputools documentation built on May 13, 2020, 9:42 a.m.