Description Usage Arguments Value Examples
View source: R/HandleDescriptives.R
A function to calculate group proportions for categorical variables in sample weighted data
1 | get_weighted_proportions(x, y)
|
x |
A vector of the factor for which proportions to be calculated. |
y |
A vector of weights for each of the values in x |
A numeric vector containing the proportions for each level of factor
1 | get_weighted_proportions(highested,sampleweights)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.